@@ -6,6 +6,10 @@
  * Implements: record_key_t (Database Record Key)
  */
 
+#include <string.h>
+#include <stdio.h>
+#include <stdlib.h>
+
 #include <sepol/boolean_record.h>
 
 typedef sepol_bool_t semanage_bool_t;
@@ -19,7 +23,6 @@ typedef semanage_bool_key_t record_key_t;
 #include "boolean_internal.h"
 #include "handle.h"
 #include "database.h"
-#include <stdlib.h>
 #include <selinux/selinux.h>
 
 /* Key */
@@ -38,14 +41,12 @@ int semanage_bool_key_extract(semanage_handle_t * handle,
 	return sepol_bool_key_extract(handle->sepolh, boolean, key);
 }
 
-hidden_def(semanage_bool_key_extract)
 
 void semanage_bool_key_free(semanage_bool_key_t * key)
 {
 	sepol_bool_key_free(key);
 }
 
-hidden_def(semanage_bool_key_free)
 
 int semanage_bool_compare(const semanage_bool_t * boolean,
 			  const semanage_bool_key_t * key)
@@ -54,7 +55,6 @@ int semanage_bool_compare(const semanage_bool_t * boolean,
 	return sepol_bool_compare(boolean, key);
 }
 
-hidden_def(semanage_bool_compare)
 
 int semanage_bool_compare2(const semanage_bool_t * boolean,
 			   const semanage_bool_t * boolean2)
@@ -63,13 +63,13 @@ int semanage_bool_compare2(const semanage_bool_t * boolean,
 	return sepol_bool_compare2(boolean, boolean2);
 }
 
-hidden_def(semanage_bool_compare2)
 
-static int semanage_bool_compare2_qsort(const semanage_bool_t ** boolean,
-					const semanage_bool_t ** boolean2)
+static int semanage_bool_compare2_qsort(const void *p1, const void *p2)
 {
+	const semanage_bool_t *const *boolean1 = p1;
+	const semanage_bool_t *const *boolean2 = p2;
 
-	return sepol_bool_compare2(*boolean, *boolean2);
+	return sepol_bool_compare2(*boolean1, *boolean2);
 }
 
 /* Name */
@@ -79,19 +79,67 @@ const char *semanage_bool_get_name(const semanage_bool_t * boolean)
 	return sepol_bool_get_name(boolean);
 }
 
-hidden_def(semanage_bool_get_name)
 
 int semanage_bool_set_name(semanage_handle_t * handle,
 			   semanage_bool_t * boolean, const char *name)
 {
-	int rc;
-	char *subname = selinux_boolean_sub(name);
+	int rc = -1;
+	const char *prefix = semanage_root();
+	const char *storename = handle->conf->store_path;
+	const char *selinux_root = selinux_policy_root();
+	char *oldroot;
+	char *olddir;
+	char *subname = NULL;
+	char *newroot = NULL;
+	char *end;
+
+	if (!selinux_root)
+		return -1;
+
+	oldroot = strdup(selinux_root);
+	if (!oldroot)
+		return -1;
+	olddir = strdup(oldroot);
+	if (!olddir)
+		goto out;
+	end = strrchr(olddir, '/');
+	if (!end)
+		goto out;
+	end++;
+	*end = '\0';
+	rc = asprintf(&newroot, "%s%s%s", prefix, olddir, storename);
+	if (rc < 0) {
+		newroot = NULL;
+		goto out;
+	}
+
+	if (strcmp(oldroot, newroot)) {
+		rc = selinux_set_policy_root(newroot);
+		if (rc)
+			goto out;
+	}
+
+	subname = selinux_boolean_sub(name);
+	if (!subname) {
+		rc = -1;
+		goto out;
+	}
+
+	if (strcmp(oldroot, newroot)) {
+		rc = selinux_set_policy_root(oldroot);
+		if (rc)
+			goto out;
+	}
+
 	rc = sepol_bool_set_name(handle->sepolh, boolean, subname);
+out:
 	free(subname);
+	free(oldroot);
+	free(olddir);
+	free(newroot);
 	return rc;
 }
 
-hidden_def(semanage_bool_set_name)
 
 /* Value */
 int semanage_bool_get_value(const semanage_bool_t * boolean)
@@ -100,7 +148,6 @@ int semanage_bool_get_value(const semanage_bool_t * boolean)
 	return sepol_bool_get_value(boolean);
 }
 
-hidden_def(semanage_bool_get_value)
 
 void semanage_bool_set_value(semanage_bool_t * boolean, int value)
 {
@@ -108,7 +155,6 @@ void semanage_bool_set_value(semanage_bool_t * boolean, int value)
 	sepol_bool_set_value(boolean, value);
 }
 
-hidden_def(semanage_bool_set_value)
 
 /* Create/Clone/Destroy */
 int semanage_bool_create(semanage_handle_t * handle,
@@ -118,7 +164,6 @@ int semanage_bool_create(semanage_handle_t * handle,
 	return sepol_bool_create(handle->sepolh, bool_ptr);
 }
 
-hidden_def(semanage_bool_create)
 
 int semanage_bool_clone(semanage_handle_t * handle,
 			const semanage_bool_t * boolean,
@@ -128,7 +173,6 @@ int semanage_bool_clone(semanage_handle_t * handle,
 	return sepol_bool_clone(handle->sepolh, boolean, bool_ptr);
 }
 
-hidden_def(semanage_bool_clone)
 
 void semanage_bool_free(semanage_bool_t * boolean)
 {
@@ -136,10 +180,9 @@ void semanage_bool_free(semanage_bool_t * boolean)
 	sepol_bool_free(boolean);
 }
 
-hidden_def(semanage_bool_free)
 
 /* Record base functions */
-record_table_t SEMANAGE_BOOL_RTABLE = {
+const record_table_t SEMANAGE_BOOL_RTABLE = {
 	.create = semanage_bool_create,
 	.key_extract = semanage_bool_key_extract,
 	.key_free = semanage_bool_key_free,
