@@ -92,8 +92,10 @@ static int bool_commit_list(semanage_handle_t * handle,
 {
 
 	SELboolean *blist = NULL;
+	const char *name;
 	unsigned int bcount = 0;
 	unsigned int i;
+	int curvalue, newvalue;
 
 	/* Allocate a sufficiently large array */
 	blist = malloc(sizeof(SELboolean) * count);
@@ -102,11 +104,18 @@ static int bool_commit_list(semanage_handle_t * handle,
 
 	/* Populate array */
 	for (i = 0; i < count; i++) {
-		blist[i].name = strdup(semanage_bool_get_name(booleans[i]));
-		bcount++;
-		if (blist[i].name == NULL)
+		name = semanage_bool_get_name(booleans[i]);
+		if (!name)
 			goto omem;
-		blist[i].value = semanage_bool_get_value(booleans[i]);
+		newvalue = semanage_bool_get_value(booleans[i]);
+		curvalue = security_get_boolean_active(name);
+		if (newvalue == curvalue)
+			continue;
+		blist[bcount].name = strdup(name);
+		if (blist[bcount].name == NULL)
+			goto omem;
+		blist[bcount].value = newvalue;
+		bcount++;
 	}
 
 	/* Commit */
@@ -132,7 +141,7 @@ static int bool_commit_list(semanage_handle_t * handle,
 }
 
 /* BOOL RECORD: ACTIVEDB extension: method table */
-record_activedb_table_t SEMANAGE_BOOL_ACTIVEDB_RTABLE = {
+static const record_activedb_table_t SEMANAGE_BOOL_ACTIVEDB_RTABLE = {
 	.read_list = bool_read_list,
 	.commit_list = bool_commit_list,
 };
