@@ -36,10 +36,10 @@ typedef struct dbase_policydb dbase_t;
 #include "semanage_store.h"
 
 /* BOOLEAN RECRORD (SEPOL): POLICYDB extension: method table */
-record_policydb_table_t SEMANAGE_BOOL_POLICYDB_RTABLE = {
+static const record_policydb_table_t SEMANAGE_BOOL_POLICYDB_RTABLE = {
 	.add = NULL,
 	.modify = NULL,
-/* FIXME: these casts depend on stucts in libsepol matching structs
+/* FIXME: these casts depend on structs in libsepol matching structs
  * in libsemanage. This is incredibly fragile - the casting gets
  * rid of warnings, but is not type safe.
  */
