@@ -25,14 +25,14 @@ typedef struct dbase_policydb dbase_t;
 /* POLICYDB dbase */
 struct dbase_policydb {
 
-	/* Backing file suffix */
-	const char *suffix;
+        /* Backing path for read-only[0] and transaction[1] */
+        const char *path[2];
 
 	/* Base record table */
-	record_table_t *rtable;
+	const record_table_t *rtable;
 
 	/* Policy extensions */
-	record_policydb_table_t *rptable;
+	const record_policydb_table_t *rptable;
 
 	sepol_policydb_t *policydb;
 
@@ -44,7 +44,7 @@ struct dbase_policydb {
 static void dbase_policydb_drop_cache(dbase_policydb_t * dbase)
 {
 
-	if (dbase->cache_serial >= 0) {
+	if (dbase && dbase->cache_serial >= 0) {
 		sepol_policydb_free(dbase->policydb);
 		dbase->cache_serial = -1;
 		dbase->modified = 0;
@@ -86,26 +86,6 @@ static int dbase_policydb_needs_resync(semanage_handle_t * handle,
 	return 0;
 }
 
-static int construct_filename(semanage_handle_t * handle,
-			      dbase_policydb_t * dbase, char **filename)
-{
-
-	const char *path = (handle->is_in_transaction) ?
-	    semanage_path(SEMANAGE_TMP, SEMANAGE_TOPLEVEL) :
-	    semanage_path(SEMANAGE_ACTIVE, SEMANAGE_TOPLEVEL);
-	size_t fname_length = strlen(path) + strlen(dbase->suffix) + 2;
-
-	char *fname = malloc(fname_length);
-	if (!fname) {
-		ERR(handle, "out of memory, could not construct database name");
-		return STATUS_ERR;
-	}
-	snprintf(fname, fname_length, "%s/%s", path, dbase->suffix);
-
-	*filename = fname;
-	return STATUS_SUCCESS;
-}
-
 static int dbase_policydb_cache(semanage_handle_t * handle,
 				dbase_policydb_t * dbase)
 {
@@ -113,7 +93,7 @@ static int dbase_policydb_cache(semanage_handle_t * handle,
 	FILE *fp = NULL;
 	sepol_policydb_t *policydb = NULL;
 	sepol_policy_file_t *pf = NULL;
-	char *fname = NULL;
+	const char *fname = NULL;
 
 	/* Check if cache is needed */
 	if (dbase->attached)
@@ -122,20 +102,19 @@ static int dbase_policydb_cache(semanage_handle_t * handle,
 	if (!dbase_policydb_needs_resync(handle, dbase))
 		return STATUS_SUCCESS;
 
-	if (construct_filename(handle, dbase, &fname) < 0)
-		goto err;
+	fname = dbase->path[handle->is_in_transaction];
 
 	if (sepol_policydb_create(&policydb) < 0) {
 		ERR(handle, "could not create policydb object");
 		goto err;
 	}
 
-	/* Try opening file 
+	/* Try opening file
 	 * ENOENT is not fatal - we just create an empty policydb */
-	fp = fopen(fname, "rb");
+	fp = fopen(fname, "rbe");
 	if (fp == NULL && errno != ENOENT) {
-		ERR(handle, "could not open %s for reading: %s",
-		    fname, strerror(errno));
+		ERR(handle, "could not open %s for reading",
+		    fname);
 		goto err;
 	}
 
@@ -164,7 +143,6 @@ static int dbase_policydb_cache(semanage_handle_t * handle,
 
 	/* Update the database policydb */
 	dbase->policydb = policydb;
-	free(fname);
 	return STATUS_SUCCESS;
 
       err:
@@ -173,7 +151,6 @@ static int dbase_policydb_cache(semanage_handle_t * handle,
 		fclose(fp);
 	sepol_policydb_free(policydb);
 	sepol_policy_file_free(pf);
-	free(fname);
 	return STATUS_ERR;
 }
 
@@ -188,7 +165,6 @@ static int dbase_policydb_flush(semanage_handle_t * handle
 	dbase->modified = 0;
 
 	/* Stub */
-	handle = NULL;
 	return STATUS_ERR;
 }
 
@@ -200,9 +176,10 @@ static int dbase_policydb_is_modified(dbase_policydb_t * dbase)
 }
 
 int dbase_policydb_init(semanage_handle_t * handle,
-			const char *suffix,
-			record_table_t * rtable,
-			record_policydb_table_t * rptable,
+			const char *path_ro,
+			const char *path_rw,
+			const record_table_t * rtable,
+			const record_policydb_table_t * rptable,
 			dbase_policydb_t ** dbase)
 {
 
@@ -212,7 +189,8 @@ int dbase_policydb_init(semanage_handle_t * handle,
 	if (!tmp_dbase)
 		goto omem;
 
-	tmp_dbase->suffix = suffix;
+	tmp_dbase->path[0] = path_ro;
+	tmp_dbase->path[1] = path_rw;
 	tmp_dbase->rtable = rtable;
 	tmp_dbase->rptable = rptable;
 	tmp_dbase->policydb = NULL;
@@ -319,9 +297,6 @@ static int dbase_policydb_del(semanage_handle_t * handle
 {
 
 	/* Stub */
-	key = NULL;
-	handle = NULL;
-	dbase = NULL;
 	return STATUS_ERR;
 }
 
@@ -332,8 +307,6 @@ static int dbase_policydb_clear(semanage_handle_t * handle
 {
 
 	/* Stub */
-	handle = NULL;
-	dbase = NULL;
 	return STATUS_ERR;
 }
 
@@ -404,7 +377,7 @@ static int dbase_policydb_iterate(semanage_handle_t * handle,
 
 struct list_handler_arg {
 	semanage_handle_t *handle;
-	record_table_t *rtable;
+	const record_table_t *rtable;
 	record_t **records;
 	int pos;
 };
@@ -462,21 +435,23 @@ static int dbase_policydb_list(semanage_handle_t * handle,
 	ERR(handle, "out of memory");
 
       err:
-	for (; list_arg.pos >= 0; list_arg.pos--)
-		dbase->rtable->free(tmp_records[list_arg.pos]);
-	free(tmp_records);
+	if (tmp_records) {
+		for (; list_arg.pos >= 0; list_arg.pos--)
+			dbase->rtable->free(tmp_records[list_arg.pos]);
+		free(tmp_records);
+	}
 	ERR(handle, "could not list records");
 	return STATUS_ERR;
 }
 
-static record_table_t *dbase_policydb_get_rtable(dbase_policydb_t * dbase)
+static const record_table_t *dbase_policydb_get_rtable(dbase_policydb_t * dbase)
 {
 
 	return dbase->rtable;
 }
 
 /* POLICYDB dbase - method table implementation */
-dbase_table_t SEMANAGE_POLICYDB_DTABLE = {
+const dbase_table_t SEMANAGE_POLICYDB_DTABLE = {
 
 	/* Cache/Transactions */
 	.cache = dbase_policydb_cache,
